@@ -142,7 +142,7 @@ def optimize_weights(data = None, starting_date = None, ending_date = None):
     print(w__)
     return w__
 
-def compute_signals_weights_perf(data = None, optimal_weights = None, starting_date = None, ending_date = None, normalization = False):
+def compute_signals_weights_perf(data = None, optimal_weights = None, starting_date = None, ending_date = None, normalization = False, n_items_per_year = 252):
     print(max(data.index))
     print(min(data.index))
     data = data[data.index >= starting_date]
@@ -155,9 +155,9 @@ def compute_signals_weights_perf(data = None, optimal_weights = None, starting_d
     optimal_signal = pd.DataFrame(data[all_sigs].values * optimal_weights, columns=all_sigs, index=data.index)
     temp_df['signal'] = optimal_signal.sum(axis=1)
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=False, normalization=normalization)
-    sharpe_strat_without = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
-    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=252 * 24, from_ret=True)
+    sharpe_strat_without = metrics.sharpe(hourly_df['perf_return'].dropna(), period=n_items_per_year, from_ret=True)
+    sharpe_under = metrics.sharpe(hourly_df['close_return'].dropna(), period=n_items_per_year, from_ret=True)
 
     hourly_df = reconstitute_signal_perf(data=temp_df, transaction_cost=True, normalization=normalization)
-    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=252 * 24, from_ret=True)
+    sharpe_strat = metrics.sharpe(hourly_df['perf_return'].dropna(), period=n_items_per_year, from_ret=True)
     return hourly_df, sharpe_strat, sharpe_strat_without, sharpe_under
\ No newline at end of file
